@@ -87,7 +87,15 @@ class BillingUtils:
         }
 
         def add_comment(value, field_name):
-            """为字段值添加注释"""
+            """
+            description:
+                为字段值添加注释
+            parameters:
+                value(Any): 字段值
+                field_name(str): 字段名称
+            return:
+                value_with_comment(str): 带注释的字段值
+            """
             if with_comments and field_name in field_comments:
                 return f"{value} # {field_comments[field_name]}"
             return value
@@ -244,7 +252,7 @@ class BillingUtils:
             return formatted_response
 
         except Exception as e:
-            feishu_alert.send(traceback.format_exc())
+            print(traceback.format_exc())
             error_response = {
                 "Message": add_comment(f"Format error: {str(e)}", "Message"),
                 "RequestId": add_comment(
@@ -326,7 +334,7 @@ class BillingUtils:
             return formatted_response
 
         except Exception as error:
-            feishu_alert.send(traceback.format_exc())
+            print(traceback.format_exc())
             error_msg = getattr(error, "message", str(error))
             # 诊断地址
             diagnose_url = ""
@@ -391,6 +399,14 @@ class BillingUtils:
             # 2) 去除首尾空白，并将内部连续空白压缩为一个空格
             # 3) 去除常见的不可见空白字符（如不间断空格、零宽空格）
             def _clean_string(value):
+                """
+                description:
+                    清洗字符串，去除注释、不可见字符并规范化空白
+                parameters:
+                    value(Any): 需要清洗的值
+                return:
+                    cleaned_value(Any): 清洗后的值
+                """
                 if not isinstance(value, str):
                     return value
                 # 去注释
@@ -473,5 +489,5 @@ class BillingUtils:
             return output_path
 
         except Exception as e:
-            feishu_alert.send(traceback.format_exc())
+            print(traceback.format_exc())
             raise Exception(f"保存账单数据失败: {str(e)}")
